local _,stash = ...
local L = stash.localization
local C = stash.constants
local settings = stash.settings
stash.frame = StashFrame

function stash.frame:Setup()
    self.TitleBg:SetHeight(19)
    self.TitleText:SetText(L["Stash"])
    self:SetMinResize(C.MIN_RESIZE_WIDTH,C.MIN_RESIZE_HEIGHT)
    self:SetMaxResize(C.MAX_RESIZE_WIDTH,C.MAX_RESIZE_HEIGHT)

    self.CloseButton:SetScript("OnKeyDown",self.CloseButton.OnKeyDown)

    if not settings.PerCharacterPosition and settings.XPos and settings.YPos and settings.Width and settings.Height then
        self:ClearAllPoints()
        self:SetPoint("BOTTOMLEFT",settings.XPos,settings.YPos)
        self:SetSize(settings.Width,settings.Height)
    end

    if C.IS_CLASSIC then
        self.TopLeftCorner:SetHeight(32) -- fixing a minor annoyance in BasicFrameTemplate
    end
end

function stash.frame:Update()
    self.ResizeGrip:SetShown(not settings.LockWindow)
end

-- called from binding or slash command to toggle window
function stash.frame:Toggle()
    stash.frame:SetShown(not stash.frame:IsVisible())
end

-- when main parent shown, always go to the itemsPanel first
function stash.frame:OnShow()
    self:Update()
    self.moneyPanel:Hide()
    self.settingsPanel:Hide()
    self.confirmPanel:Hide()
    self.itemsPanel:Show()
end

function stash.frame:OnHide()
    if settings.ResetOnClose then
        stash.filterPanel:Reset()
    end
end

function stash.frame:OnMouseDown()
    if not settings.LockWindow then
        self:StartMoving()
    end
end

function stash.frame:OnMouseUp()
    if not settings.LockWindow then
        self:StopMovingOrSizing()
        self:RememberPosition()
    end
end

function stash.frame.ResizeGrip:OnMouseDown()
    if not settings.LockWindow then
        self:GetParent():StartSizing()
    end
end

function stash.frame.ResizeGrip:OnMouseUp()
    if not settings.LockWindow then
        self:GetParent():StopMovingOrSizing()
        self:GetParent():RememberPosition()
    end
end

-- using close button to watch OnKeyDown for ESC being hit to dismiss panels/window
function stash.frame.CloseButton:OnKeyDown(key)
    if key=="TAB" and settings.TabFocus and stash.itemsPanel:IsVisible() then -- Tab to grab searchbox focus
        stash.itemsPanel:GrabSearchBoxFocus()
        self:SetPropagateKeyboardInput(false)
        return
    elseif key==GetBindingKey("TOGGLEGAMEMENU") then
        if stash.filterPanel:IsMenuOpen() then -- if a menu is up, close it
            stash.filterPanel:CloseMenu()
            self:SetPropagateKeyboardInput(false)
            return
        elseif stash.confirmPanel:IsVisible() then -- if confirmPanel up, go back to settingsPanel
            stash.confirmPanel:Hide()
            stash.settingsPanel:Show()
            self:SetPropagateKeyboardInput(false)
            return
        elseif stash.settingsPanel:IsVisible() then -- if settingsPanel up, go back to itemsPanel
            stash.settingsPanel:Hide()
            stash.itemsPanel:Show()
            self:SetPropagateKeyboardInput(false)
            return
        elseif stash.moneyPanel:IsVisible() then -- if moneyPanel up, go back to itemsPanel
            stash.moneyPanel:Hide()
            stash.itemsPanel:Show()
            self:SetPropagateKeyboardInput(false)
            return
        elseif not settings.NoESCape then -- otherwise close stash window
            stash.frame:Hide()
            self:SetPropagateKeyboardInput(false)
            return
        end
    end
    self:SetPropagateKeyboardInput(true)
end

-- for use whenever the window moves/resizes (or PerCharacterPosition setting changes)
function stash.frame:RememberPosition()
    settings.XPos = self:GetLeft()
    settings.YPos = self:GetBottom()
    settings.Width = self:GetWidth()
    settings.Height = self:GetHeight()
end

-- when changing modes
function stash.frame:Configure()

end
